@@ -1,8 +1,9 @@
+# A hack to make CI builds work on windows/appveyor
+# See https://github.com/krlmlr/r-appveyor/issues/91
 .libPaths(c("C:/RLibrary",.libPaths()))
-.libPaths()
+
 library(testthat)
 library(reticulate)
-py_discover_config("docker")
 library(docker)
 
 test_check("docker")
