@@ -1,7 +1,8 @@
+# A hack to make CI builds work on windows/appveyor
+# See https://github.com/krlmlr/r-appveyor/issues/91
 .libPaths(c("C:/RLibrary",.libPaths()))
-.libPaths()
+
 library(reticulate)
-py_discover_config("docker")
 library(docker)
 
 # helper function to skip tests if we don't have the 'docker' module
@@ -19,32 +20,38 @@ skip_if_no_docker_engine <- function() {
   }
 }
 
-skip_os_platform <- function(platform = 'windows') {
-  if(platform == .Platform$OS.type) {
-    skip(paste0("Skipping test: Unsupported platform:", platform))
-  }
-}
-
 context("Hello World")
 
 test_that("docker python module is loaded", {
+  skip_on_cran()
+  skip_on_bioc()
   skip_if_no_docker_module()
   expect_true(is.object(docker))
   expect_true(!is.null(docker$version))
 })
 
 test_that("docker API litmus test passes on *nix", {
+  skip_on_cran()
+  skip_on_bioc()
+  skip_on_os("windows")
   skip_if_no_docker_engine()
-  skip_os_platform("windows")
   c <- docker$from_env()
   s <- c$containers$run('alpine', 'echo -n "Hello World!"', remove=TRUE)
-  expect_match(s$decode("UTF-8"), "Hello World!")
+  if(!inherits(s,'character')) { # python 2 vs 3
+    s <- s$decode('UTF-8')
+  }
+  expect_match(s, "Hello World!")
 })
 
 test_that("docker API litmus test passes on windows", {
+  skip_on_cran()
+  skip_on_bioc()
+  skip_on_os(c("linux", "mac", "solaris"))
   skip_if_no_docker_engine()
-  skip_os_platform("unix")
   c <- docker$from_env()
   s <- c$containers$run('microsoft/nanoserver', 'CMD /q /c echo "Hello World!"', remove=TRUE)
-  expect_match(s$decode("UTF-8"), "Hello World!")
+  if(!inherits(s,'character')) { # python 2 vs 3
+    s <- s$decode('UTF-8')
+  }
+  expect_match(s, "Hello World!")
 })
